<KrossScripting>
  <collection comment="Tools" name="tools" text="Tools" >
    <script text="Norwegian Bokmål Simultaneous"
            name="nb-simultaneous"
            file="nb-simultaneous.py"
            interpreter="python">
    </script>
  </collection>
</KrossScripting>
